<?php
/**
* @package Portmanat
*/
/*
Plugin Name: Portmanat Card
Plugin URI: https://portmanat.az/partners/list
Description: This is Portmanat Card Api Plugin. You can transfer money over Plastic Card.
Version: 1.0.0
Author: Portmanat
License: GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/
require(dirname(dirname(dirname(dirname(__FILE__)))) . '/wp-load.php');
add_action('plugins_loaded', 'init_WC_Portmanat_Card_Gateway', 0);
function init_WC_Portmanat_Card_Gateway() {
    if(!class_exists('WC_Payment_Gateway')) return;
    class WC_Portmanat_Card_Gateway extends WC_Payment_Gateway{

        public function __construct(){
            $this->id = 'portmanatcard';
            $this->has_fields         = false;
            $this->method_title       = 'Portmanat Card';
            $this->method_description = __( 'Portmanat Payment Card', 'woocommerce_portmanatcard' );
            $this->liveurl            = 'https://psp.mps.az/process';
            $this->init_form_fields();
            $this->init_settings();
            $this->title              =  $this->settings['title'];
            $this->description        =  $this->settings['description'];
            $this->service_id        = $this->settings['service_id'];
            $this->service_key  = $this->settings['service_key'];
            $this->icon               = '';
            add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
            add_action( 'woocommerce_receipt_'. $this->id, array( $this, 'receipt_page' ) );
            add_action('woocommerce_api_wc_portmanat', array($this, 'result'));
        }
        public function init_form_fields(){
            $this->form_fields = array(
                'enabled' => array(
                    'title' => __( 'Enable/Disable', 'woocommerce_portmanatcard' ),
                    'type' => 'checkbox',
                    'label' => __( 'Enable', 'woocommerce_portmanatcard' ),
                    'default' => 'yes'
                                ),
                'title' => array(
                    'title' => __( 'Title', 'woocommerce_portmanatcard' ),
                    'type' => 'text',
                    'description' => __( 'This controls the title which the user sees during checkout.', 'woocommerce_portmanatcard' ),
                    'default' => 'Portmanat Card',
                    'desc_tip' => true,
                                ),
                'description' => array(
                    'title' => __( 'Description', 'woocommerce_portmanatcard' ),
                    'type' => 'textarea',
                    'description' => __( 'This controls the description which the user sees during checkout.', 'woocommerce_portmanatcard' ),
                    'default' => __( 'Pay with portmanat card gateway.', 'woocommerce_portmanatcard' ),
                ),
                'service_id' => array(
                    'title' => __( 'Servis ID', 'woocommerce_portmanatcard' ),
                    'type' => 'text',
                    'description' => __( 'Servis ID', 'woocommerce_portmanatcard' ),
                ),
                'service_key' => array(
                    'title' => __( 'Service Key', 'woocommerce_portmanatcard' ),
                    'type' => 'password',
                    'description' => __( 'Service Key', 'woocommerce_portmanatcard' ),
                ),
            );
        }
        function process_payment($order_id){
            $order = new WC_Order($order_id);
            return array(
                'result' => 'success',
                'redirect'  => add_query_arg('order', $order->id, add_query_arg('key', $order->order_key, get_permalink(woocommerce_get_page_id('pay'))))
            );
        }
        public function receipt_page($order){
            echo '<p>'.__('Thank you for your order, please click the button below to pay.', 'woocommerce').'</p>';
            echo $this->generate_form($order);
        }
        public function generate_form($order_id){
            $order = new WC_Order( $order_id );
            $action_adr = $this->liveurl;
            $args = array(
                'service_id'        => $this->service_id,
                'client_rrn'        => $order_id,
                'amount'      => $order->order_total,
                'client_ip' =>$_SERVER['REMOTE_ADDR'],
                'hash' =>hash_hmac('sha256', $this->service_id.$order_id.$order->order_total, $this->service_key)
                        );
            $args_array = array();
            foreach ($args as $key => $value){
                $args_array[] = '<input type="hidden" name="'.esc_attr($key).'" value="'.esc_attr($value).'" />';
            }
            return
                    '<form action="'.esc_url($action_adr).'" method="POST" id="portmanat_payment_form">'.
                    '<input type="submit" class="button alt" id="submit_portmanat_button" value="'.__('Ödəyin', 'woocommerce').'" /> <a class="button cancel" href="'.$order->get_cancel_order_url().'">'.__('Ödənişi ləğv edin', 'woocommerce').'</a>'."\n".
                    implode("\n", $args_array).
                    '</form>';
        }
    }
}
add_filter( 'woocommerce_payment_gateways', 'add_WC_Portmanat_Card_Gateway' );
function add_WC_Portmanat_Card_Gateway( $methods ){
    $methods[] = 'WC_Portmanat_Card_Gateway';
    return $methods;
}